@@ -16,6 +16,15 @@ def test_cve_json():
         return json.loads(fp.read())
 
 
+@pytest.fixture
+def test_cve_wconfig_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "cve_wconfig_data.json"
+    )
+    with open(test_cve_data, "r") as fp:
+        return json.loads(fp.read())
+
+
 def test_convert(test_cve_json):
     nvdlatest = NvdSource()
     data = nvdlatest.convert(test_cve_json)
@@ -29,6 +38,20 @@ def test_convert(test_cve_json):
             assert detail.package_type
 
 
+def test_convert2(test_cve_wconfig_json):
+    nvdlatest = NvdSource()
+    data = nvdlatest.convert(test_cve_wconfig_json)
+    assert len(data) == 1
+    for v in data:
+        details = v.details
+        for detail in details:
+            assert detail
+            assert detail.severity
+            assert detail.package
+            assert detail.package_type
+            assert not detail.fixed_location
+
+
 @pytest.mark.skip(reason="This downloads and tests with live data")
 def test_nvd_download():
     nvdlatest = NvdSource()
