@@ -121,7 +121,6 @@ class NvdSource(VulnerabilitySource):
     def convert_vuln(vuln):
         id = vuln["cve"]["CVE_data_meta"]["ID"]
         problem_type = ""
-
         if (
             vuln["cve"]["problemtype"]["problemtype_data"]
             and vuln["cve"]["problemtype"]["problemtype_data"][0]["description"]
@@ -210,8 +209,9 @@ class NvdSource(VulnerabilitySource):
                     )
                     detail["source_update_time"] = vuln["lastModifiedDate"]
                     cpe_details_list.append(detail)
-                else:
-                    fix_cpe_uri = cpe["cpe23Uri"]
+                else: # cpe is not vulnerable
+                    if node["operator"] == "OR":
+                        fix_cpe_uri = cpe["cpe23Uri"]
             # Add fix version details
             for det in cpe_details_list:
                 if fix_cpe_uri:
