@@ -281,12 +281,16 @@ def convert_to_semver(version):
     }
     # Trim based on known prerelease strings
     if ver.get("prerelease"):
-        pre_str = ver.get("prerelease", "").lower()
-        for s in KNOWN_PRERELEASE_STR:
-            if s in pre_str:
-                ver["prerelease"] = None
-                ver["build"] = None
-                break
+        try:
+            prefloat = float(ver.get("prerelease"))
+            ver["prerelease"] = int(prefloat)
+        except Exception:
+            pre_str = ver.get("prerelease", "").lower()
+            for s in KNOWN_PRERELEASE_STR:
+                if s in pre_str:
+                    ver["prerelease"] = 0
+                    ver["build"] = 0
+                    break
 
     ver = VersionInfo(**ver)
     rest = match.string[match.end() :]  # noqa:E203
@@ -304,7 +308,7 @@ def convert_to_semver(version):
             minor=0,
             patch=0,
             prerelease=int(f"{version.replace('-', '')[:8]}000000"),
-            build=None,
+            build=0,
         )
     if not number_part:
         rest = None
@@ -363,14 +367,7 @@ def version_compare(
             "0.0.0" if min_version == "*" else min_version
         )
         max_semver, maxrest = convert_to_semver(max_version)
-        if (
-            compare_semver
-            and min_semver
-            and max_semver
-            and not comprest
-            and not minrest
-            and not maxrest
-        ):
+        if compare_semver and min_semver and max_semver and not minrest and not maxrest:
             min_value = compare_semver.compare(min_semver)
             max_value = compare_semver.compare(max_semver)
             # If we are confident about the versions post upgrade then return True
